==> vdocipher_flutter-2.6.0.tar.gz: android/src/main/java/com/vdocipher/flutter/vdoplayer/VdocipherFlutterPlugin.java <==
package com.vdocipher.flutter.vdoplayer;

import android.app.Activity;
import android.content.Context;
import android.util.Base64;

import androidx.annotation.NonNull;

import com.vdocipher.aegis.media.ErrorDescription;
import com.vdocipher.aegis.offline.DownloadOptions;
import com.vdocipher.aegis.offline.DownloadRequest;
import com.vdocipher.aegis.offline.DownloadSelections;
import com.vdocipher.aegis.offline.DownloadStatus;
import com.vdocipher.aegis.offline.OptionsDownloader;
import com.vdocipher.aegis.offline.VdoDownloadManager;
import com.vdocipher.flutter.vdoplayer.offline.VdoDownloader;

import org.json.JSONException;
import org.json.JSONObject;

import java.io.UnsupportedEncodingException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.BinaryMessenger;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;

/**
 * VdocipherFlutterPlugin
 */
public class VdocipherFlutterPlugin implements FlutterPlugin, MethodCallHandler, ActivityAware {

    private static final String VDO_PLAYER_VIEW_TYPE = "com.vdocipher.flutter/vdoplayerview";
    private static final String VDO_PLAYER_UI_VIEW_TYPE = "com.vdocipher.flutter/vdoplayerui";

    /// The MethodChannel that will the communication between Flutter and native Android
    ///
    /// This local reference serves to register the plugin with the Flutter Engine and unregister it
    /// when the Flutter Engine is detached from the Activity
    private MethodChannel channel;
    private Activity activity = null;

    FlutterPluginBinding flutterPluginBinding;

    @Override
    public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
        channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "com.vdocipher.flutter");
        channel.setMethodCallHandler(this);
        this.flutterPluginBinding = flutterPluginBinding;
        flutterPluginBinding
                .getPlatformViewRegistry()
                .registerViewFactory(VDO_PLAYER_VIEW_TYPE,
                        new VdoPlayerPlatformViewFactory(flutterPluginBinding.getBinaryMessenger(), null));
        configureOptionDownloader(flutterPluginBinding.getApplicationContext(), flutterPluginBinding.getBinaryMessenger());
        configureVdoDownloadChannels(flutterPluginBinding.getApplicationContext(), flutterPluginBinding.getBinaryMessenger());
    }

    @Override
    public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
        if (call.method.equals("getNativeAndroidLibraryVersion")) {
            result.success(BuildConfig.VDO_VERSION_NAME);
        } else {
            result.notImplemented();
        }
    }

    @Override
    public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
        channel.setMethodCallHandler(null);
    }

    @Override
    public void onAttachedToActivity(@NonNull ActivityPluginBinding binding) {
        this.activity = binding.getActivity();
        flutterPluginBinding
                .getPlatformViewRegistry()
                .registerViewFactory(VDO_PLAYER_UI_VIEW_TYPE,
                        new VdoPlayerUiPlatformViewFactory(flutterPluginBinding.getBinaryMessenger(), null, activity));
    }

    @Override
    public void onDetachedFromActivityForConfigChanges() {

    }

    @Override
    public void onReattachedToActivityForConfigChanges(@NonNull ActivityPluginBinding binding) {

    }

    @Override
    public void onDetachedFromActivity() {

    }

    private void configureOptionDownloader(Context context, BinaryMessenger binaryMessenger) {
        MethodChannel methodChannel = new MethodChannel(binaryMessenger, "com.vdocipher.flutter.option_downloader");
        OptionsDownloader.Callback callback = new OptionsDownloader.Callback() {
            @Override
            public void onOptionsReceived(DownloadOptions downloadOptions) {
                Map<String, Object> arguments = new HashMap<>();
                arguments.put("downloadOptions", MessageUtils.downloadOptionsMap(downloadOptions));
                methodChannel.invokeMethod("onOptionsReceived", arguments);
            }

            @Override
            public void onOptionsNotReceived(ErrorDescription errorDescription) {
                Map<String, Object> arguments = new HashMap<>();
                arguments.put("errorDescription", MessageUtils.errorInfoMap(errorDescription));
                methodChannel.invokeMethod("onOptionsNotReceived", arguments);
            }
        };
        OptionsDownloader optionsDownloader = new OptionsDownloader(context);
        methodChannel.setMethodCallHandler((call, result) -> {
            switch (call.method) {
                case "downloadOptionsWithOtp":
                    HashMap<String, Object> arguments = (HashMap<String, Object>) call.arguments;
                    String otp = (String) arguments.get("otp");
                    String playbackInfo = (String) arguments.get("playbackInfo");
                    String customPlayerId = (String) arguments.get("customPlayerId");
                    if (otp != null && playbackInfo != null)
                        optionsDownloader.downloadOptionsWithOtp(otp, playbackInfo, customPlayerId, callback);
                    break;
                case "cancel":
                    optionsDownloader.cancel();
            }
        });
    }

    private void configureVdoDownloadChannels(Context context, BinaryMessenger binaryMessenger) {
        MethodChannel methodChannel = new MethodChannel(binaryMessenger, "com.vdocipher.flutter.video_downloader");
        if (android.os.Build.VERSION.SDK_INT < android.os.Build.VERSION_CODES.LOLLIPOP) {
            return;
        }
        VdoDownloader vdoDownloader = VdoDownloader.getInstance(context);
        VdoDownloadManager.EventListener eventListener = new VdoDownloadManager.EventListener() {
            @Override
            public void onQueued(String mediaId, DownloadStatus downloadStatus) {
                HashMap<String, Object> values = new HashMap<>();
                values.put("mediaId", mediaId);
                values.put("downloadStatus", MessageUtils.downloadStatusMap(downloadStatus));
                methodChannel.invokeMethod("onQueued", values);
            }

            @Override
            public void onChanged(String mediaId, DownloadStatus downloadStatus) {
                HashMap<String, Object> values = new HashMap<>();
                values.put("mediaId", mediaId);
                values.put("downloadStatus", MessageUtils.downloadStatusMap(downloadStatus));
                methodChannel.invokeMethod("onChanged", values);
            }

            @Override
            public void onCompleted(String mediaId, DownloadStatus downloadStatus) {
                HashMap<String, Object> values = new HashMap<>();
                values.put("mediaId", mediaId);
                values.put("downloadStatus", MessageUtils.downloadStatusMap(downloadStatus));
                methodChannel.invokeMethod("onCompleted", values);
            }

            @Override
            public void onFailed(String mediaId, DownloadStatus downloadStatus) {
                HashMap<String, Object> values = new HashMap<>();
                values.put("mediaId", mediaId);
                values.put("downloadStatus", MessageUtils.downloadStatusMap(downloadStatus));
                methodChannel.invokeMethod("onFailed", values);
            }

            @Override
            public void onDeleted(String mediaId) {
                HashMap<String, Object> values = new HashMap<>();
                values.put("mediaId", mediaId);
                methodChannel.invokeMethod("onDeleted", values);
            }
        };

        methodChannel.setMethodCallHandler((call, result) -> {
            switch (call.method) {
                case "addEventListener":
                    vdoDownloader.addEventListener(eventListener);
                    break;
                case "removeEventListener":
                    vdoDownloader.removeEventListener(eventListener);
                    break;
                case "enqueue":
                    HashMap<String, Object> arguments = (HashMap<String, Object>) call.arguments;
                    HashMap<String, Object> downloadRequestMap = (HashMap<String, Object>) arguments.get("arguments");
                    HashMap<String, Object> downloadSelectionMap = (HashMap<String, Object>) downloadRequestMap.get("downloadSelections");
                    HashMap<String, Object> downloadOptionsMap = (HashMap<String, Object>) downloadSelectionMap.get("downloadOptions");

                    String otp = (String) downloadOptionsMap.get("otp");
                    String playbackInfo = (String) downloadOptionsMap.get("playbackInfo");
                    String customPlayerId = (String) downloadOptionsMap.get("customPlayerId");


                    new OptionsDownloader(context).downloadOptionsWithOtp(otp, playbackInfo, customPlayerId, new OptionsDownloader.Callback() {
                        @Override
                        public void onOptionsReceived(DownloadOptions options) {
                            DownloadRequest downloadRequest = MessageUtils.downloadRequestFromMap(options, (HashMap<String, Object>) arguments.get("arguments"));
                            DownloadRequest finalDownloadRequest = new DownloadRequest.Builder(new DownloadSelections(options, downloadRequest.downloadSelections.selectedTrackIndices))
                                    .build();
                            vdoDownloader.enqueue(finalDownloadRequest);
                        }

                        @Override
                        public void onOptionsNotReceived(ErrorDescription errDesc) {

                        }
                    });
                    break;
                case "remove": {
                    String mediaId = (String) call.arguments;
                    vdoDownloader.remove(mediaId);
                }
                break;
                case "stopDownload": {
                    String mediaId = (String) call.arguments;
                    vdoDownloader.stopDownload(mediaId);
                }
                break;
                case "resumeDownload": {
                    String mediaId = (String) call.arguments;
                    vdoDownloader.resumeDownload(mediaId);
                }
                break;
                case "query": {
                    HashMap<String, Object> queryMap = (HashMap<String, Object>) call.arguments;
                    List<String> mediaIds = (List<String>) queryMap.get("mediaIds");
                    List<Integer> statues = (List<Integer>) queryMap.get("statues");
                    int[] primitiveStatues = new int[statues.size()];
                    for (int i = 0; i < statues.size(); i++) {
                        primitiveStatues[i] = statues.get(i);
                    }
                    VdoDownloadManager.Query query = new VdoDownloadManager.Query();
                    if (mediaIds != null && mediaIds.size() > 0)
                        query.setFilterByMediaId(mediaIds.toArray(new String[0]));
                    if (primitiveStatues.length > 0)
                        query.setFilterByStatus(primitiveStatues);
                    vdoDownloader.query(query, list -> {
                        List<HashMap<String, Object>> downloadStatusMapList = new ArrayList<>();
                        for (DownloadStatus downloadStatus : list) {
                            downloadStatusMapList.add(MessageUtils.downloadStatusMap(downloadStatus));
                        }
                        result.success(downloadStatusMapList);
                    });
                }
                break;
                case "isExpired": {
                    String mediaId = (String) call.arguments;
                    vdoDownloader.query(new VdoDownloadManager.Query().setFilterByMediaId(mediaId), list -> {
                        if (list.isEmpty()) {
                            result.success(false);
                        } else {
                            DownloadStatus downloadStatus = list.get(0);
                            boolean isExpired = downloadStatus.isExpired(context);
                            result.success(isExpired);
                        }
                    });
                }
                break;
            }
        });
    }

    private static String extractMediaId(String playbackInfo)
            throws IllegalArgumentException, UnsupportedEncodingException, JSONException {
        if (playbackInfo == null || playbackInfo.isEmpty()) {
            throw new IllegalArgumentException();
        }
        // also throws IllegalArgumentException
        return new JSONObject(
                new String(Base64.decode(playbackInfo, Base64.DEFAULT), "UTF-8"))
                .getString("videoId");
    }
}

==> vdocipher_flutter-2.6.5.tar.gz: android/src/main/java/com/vdocipher/flutter/vdoplayer/VdocipherFlutterPlugin.java <==
package com.vdocipher.flutter.vdoplayer;

import android.app.Activity;
import android.content.Context;
import android.util.Base64;
import android.util.Log;

import androidx.annotation.NonNull;

import com.vdocipher.aegis.media.ErrorDescription;
import com.vdocipher.aegis.offline.DownloadOptions;
import com.vdocipher.aegis.offline.DownloadRequest;
import com.vdocipher.aegis.offline.DownloadSelections;
import com.vdocipher.aegis.offline.DownloadStatus;
import com.vdocipher.aegis.offline.OptionsDownloader;
import com.vdocipher.aegis.offline.VdoDownloadManager;
import com.vdocipher.flutter.vdoplayer.offline.VdoDownloader;

import org.json.JSONException;
import org.json.JSONObject;

import java.io.UnsupportedEncodingException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.BinaryMessenger;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;

/**
 * VdocipherFlutterPlugin
 */
public class VdocipherFlutterPlugin implements FlutterPlugin, MethodCallHandler, ActivityAware {

    private static final String VDO_PLAYER_VIEW_TYPE = "com.vdocipher.flutter/vdoplayerview";
    private static final String VDO_PLAYER_UI_VIEW_TYPE = "com.vdocipher.flutter/vdoplayerui";

    /// The MethodChannel that will the communication between Flutter and native Android
    ///
    /// This local reference serves to register the plugin with the Flutter Engine and unregister it
    /// when the Flutter Engine is detached from the Activity
    private MethodChannel channel;
    private Activity activity = null;

    FlutterPluginBinding flutterPluginBinding;

    @Override
    public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
        channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "com.vdocipher.flutter");
        channel.setMethodCallHandler(this);
        this.flutterPluginBinding = flutterPluginBinding;
        flutterPluginBinding
                .getPlatformViewRegistry()
                .registerViewFactory(VDO_PLAYER_VIEW_TYPE,
                        new VdoPlayerPlatformViewFactory(flutterPluginBinding.getBinaryMessenger(), null));
        configureOptionDownloader(flutterPluginBinding.getApplicationContext(), flutterPluginBinding.getBinaryMessenger());
        configureVdoDownloadChannels(flutterPluginBinding.getApplicationContext(), flutterPluginBinding.getBinaryMessenger());
    }

    @Override
    public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
        if (call.method.equals("getNativeAndroidLibraryVersion")) {
            result.success(BuildConfig.VDO_VERSION_NAME);
        } else {
            result.notImplemented();
        }
    }

    @Override
    public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
        channel.setMethodCallHandler(null);
    }

    @Override
    public void onAttachedToActivity(@NonNull ActivityPluginBinding binding) {
        this.activity = binding.getActivity();
        flutterPluginBinding
                .getPlatformViewRegistry()
                .registerViewFactory(VDO_PLAYER_UI_VIEW_TYPE,
                        new VdoPlayerUiPlatformViewFactory(flutterPluginBinding.getBinaryMessenger(), null, activity));
    }

    @Override
    public void onDetachedFromActivityForConfigChanges() {

    }

    @Override
    public void onReattachedToActivityForConfigChanges(@NonNull ActivityPluginBinding binding) {

    }

    @Override
    public void onDetachedFromActivity() {

    }

    private void configureOptionDownloader(Context context, BinaryMessenger binaryMessenger) {
        MethodChannel methodChannel = new MethodChannel(binaryMessenger, "com.vdocipher.flutter.option_downloader");
        OptionsDownloader.Callback callback = new OptionsDownloader.Callback() {
            @Override
            public void onOptionsReceived(DownloadOptions downloadOptions) {
                Map<String, Object> arguments = new HashMap<>();
                arguments.put("downloadOptions", MessageUtils.downloadOptionsMap(downloadOptions));
                methodChannel.invokeMethod("onOptionsReceived", arguments);
            }

            @Override
            public void onOptionsNotReceived(ErrorDescription errorDescription) {
                Map<String, Object> arguments = new HashMap<>();
                arguments.put("errorDescription", MessageUtils.errorInfoMap(errorDescription));
                methodChannel.invokeMethod("onOptionsNotReceived", arguments);
            }
        };
        OptionsDownloader optionsDownloader = new OptionsDownloader(context);
        methodChannel.setMethodCallHandler((call, result) -> {
            switch (call.method) {
                case "downloadOptionsWithOtp": {
                    HashMap<String, Object> arguments = (HashMap<String, Object>) call.arguments;
                    String otp = (String) arguments.get("otp");
                    String playbackInfo = (String) arguments.get("playbackInfo");
                    String customPlayerId = (String) arguments.get("customPlayerId");
                    if (otp != null && playbackInfo != null)
                        optionsDownloader.downloadOptionsWithOtp(otp, playbackInfo, customPlayerId, callback);
                }
                break;
                case "downloadOptionsWithToken": {
                    HashMap<String, Object> arguments = (HashMap<String, Object>) call.arguments;
                    String token = (String) arguments.get("token");
                    String videoId = (String) arguments.get("videoId");
                    String customPlayerId = (String) arguments.get("customPlayerId");
                    if (token != null && videoId != null)
                    {
                        optionsDownloader.downloadOptionsWithToken(token, videoId, customPlayerId, callback);
                    }
                }
                break;
                case "cancel":
                    optionsDownloader.cancel();
            }
        });
    }

    private void configureVdoDownloadChannels(Context context, BinaryMessenger binaryMessenger) {
        MethodChannel methodChannel = new MethodChannel(binaryMessenger, "com.vdocipher.flutter.video_downloader");
        if (android.os.Build.VERSION.SDK_INT < android.os.Build.VERSION_CODES.LOLLIPOP) {
            return;
        }
        VdoDownloader vdoDownloader = VdoDownloader.getInstance(context);
        VdoDownloadManager.EventListener eventListener = new VdoDownloadManager.EventListener() {
            @Override
            public void onQueued(String mediaId, DownloadStatus downloadStatus) {
                HashMap<String, Object> values = new HashMap<>();
                values.put("mediaId", mediaId);
                values.put("downloadStatus", MessageUtils.downloadStatusMap(downloadStatus));
                methodChannel.invokeMethod("onQueued", values);
            }

            @Override
            public void onChanged(String mediaId, DownloadStatus downloadStatus) {
                HashMap<String, Object> values = new HashMap<>();
                values.put("mediaId", mediaId);
                values.put("downloadStatus", MessageUtils.downloadStatusMap(downloadStatus));
                methodChannel.invokeMethod("onChanged", values);
            }

            @Override
            public void onCompleted(String mediaId, DownloadStatus downloadStatus) {
                HashMap<String, Object> values = new HashMap<>();
                values.put("mediaId", mediaId);
                values.put("downloadStatus", MessageUtils.downloadStatusMap(downloadStatus));
                methodChannel.invokeMethod("onCompleted", values);
            }

            @Override
            public void onFailed(String mediaId, DownloadStatus downloadStatus) {
                HashMap<String, Object> values = new HashMap<>();
                values.put("mediaId", mediaId);
                values.put("downloadStatus", MessageUtils.downloadStatusMap(downloadStatus));
                methodChannel.invokeMethod("onFailed", values);
            }

            @Override
            public void onDeleted(String mediaId) {
                HashMap<String, Object> values = new HashMap<>();
                values.put("mediaId", mediaId);
                methodChannel.invokeMethod("onDeleted", values);
            }
        };

        methodChannel.setMethodCallHandler((call, result) -> {
            switch (call.method) {
                case "addEventListener":
                    vdoDownloader.addEventListener(eventListener);
                    break;
                case "removeEventListener":
                    vdoDownloader.removeEventListener(eventListener);
                    break;
                case "enqueue": {
                    HashMap<String, Object> arguments = (HashMap<String, Object>) call.arguments;
                    HashMap<String, Object> downloadRequestMap = (HashMap<String, Object>) arguments.get("arguments");
                    HashMap<String, Object> downloadSelectionMap = (HashMap<String, Object>) downloadRequestMap.get("downloadSelections");
                    HashMap<String, Object> downloadOptionsMap = (HashMap<String, Object>) downloadSelectionMap.get("downloadOptions");

                    String otp = (String) downloadOptionsMap.get("otp");
                    String token = (String) downloadOptionsMap.get("token");
                    String mediaId = (String) downloadOptionsMap.get("mediaId");
                    String playbackInfo = (String) downloadOptionsMap.get("playbackInfo");
                    String customPlayerId = (String) downloadOptionsMap.get("customPlayerId");

                    OptionsDownloader.Callback optionDownloadCallback = new OptionsDownloader.Callback() {
                        @Override
                        public void onOptionsReceived(DownloadOptions options) {
                            DownloadRequest downloadRequest = MessageUtils.downloadRequestFromMap(options, (HashMap<String, Object>) arguments.get("arguments"));
                            DownloadRequest finalDownloadRequest = new DownloadRequest.Builder(new DownloadSelections(options, downloadRequest.downloadSelections.selectedTrackIndices))
                                    .build();
                            vdoDownloader.enqueue(finalDownloadRequest);
                        }

                        @Override
                        public void onOptionsNotReceived(ErrorDescription errDesc) {

                        }
                    };

                    if (otp != null && !otp.isEmpty() && playbackInfo != null) {
                        new OptionsDownloader(context).downloadOptionsWithOtp(otp, playbackInfo, customPlayerId, optionDownloadCallback);
                    } else if (token != null && !token.isEmpty() && mediaId != null) {
                        new OptionsDownloader(context).downloadOptionsWithToken(token, mediaId, customPlayerId, optionDownloadCallback);
                    }
                }
                break;
                case "remove": {
                    String mediaId = (String) call.arguments;
                    vdoDownloader.remove(mediaId);
                }
                break;
                case "stopDownload": {
                    String mediaId = (String) call.arguments;
                    vdoDownloader.stopDownload(mediaId);
                }
                break;
                case "resumeDownload": {
                    String mediaId = (String) call.arguments;
                    vdoDownloader.resumeDownload(mediaId);
                }
                break;
                case "query": {
                    HashMap<String, Object> queryMap = (HashMap<String, Object>) call.arguments;
                    List<String> mediaIds = (List<String>) queryMap.get("mediaIds");
                    List<Integer> statues = (List<Integer>) queryMap.get("statues");
                    int[] primitiveStatues = new int[statues.size()];
                    for (int i = 0; i < statues.size(); i++) {
                        primitiveStatues[i] = statues.get(i);
                    }
                    VdoDownloadManager.Query query = new VdoDownloadManager.Query();
                    if (mediaIds != null && mediaIds.size() > 0)
                        query.setFilterByMediaId(mediaIds.toArray(new String[0]));
                    if (primitiveStatues.length > 0)
                        query.setFilterByStatus(primitiveStatues);
                    vdoDownloader.query(query, list -> {
                        List<HashMap<String, Object>> downloadStatusMapList = new ArrayList<>();
                        for (DownloadStatus downloadStatus : list) {
                            downloadStatusMapList.add(MessageUtils.downloadStatusMap(downloadStatus));
                        }
                        result.success(downloadStatusMapList);
                    });
                }
                break;
                case "isExpired": {
                    String mediaId = (String) call.arguments;
                    vdoDownloader.query(new VdoDownloadManager.Query().setFilterByMediaId(mediaId), list -> {
                        if (list.isEmpty()) {
                            result.success(false);
                        } else {
                            DownloadStatus downloadStatus = list.get(0);
                            boolean isExpired = downloadStatus.isExpired(context);
                            result.success(isExpired);
                        }
                    });
                }
                break;
            }
        });
    }

    private static String extractMediaId(String playbackInfo)
            throws IllegalArgumentException, UnsupportedEncodingException, JSONException {
        if (playbackInfo == null || playbackInfo.isEmpty()) {
            throw new IllegalArgumentException();
        }
        // also throws IllegalArgumentException
        return new JSONObject(
                new String(Base64.decode(playbackInfo, Base64.DEFAULT), "UTF-8"))
                .getString("videoId");
    }
}
